@@ -73,10 +73,10 @@ class BaseAOQuality(object):
         self.value = value
 
     @classmethod
-    def from_ms_list(cls, ms_files):
-        a = cls(ms_files[0])
+    def from_ms_list(cls, ms_files, verbose=True):
+        a = cls(ms_files[0], verbose=verbose)
         for ms_file in ms_files[1:]:
-            a.add(cls(ms_file))
+            a.add(cls(ms_file, verbose=True))
 
         return a
 
